@@ -1,10 +1,10 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LxQt - a lightweight, Qt based, desktop toolset
+ * LXQt - a lightweight, Qt based, desktop toolset
  * http://razor-qt.org, http://lxde.org/
  *
- * Copyright: 2010-2011 LxQt team
+ * Copyright: 2010-2011 LXQt team
  * Authors:
  *   Petr Vanek <petr@scribus.info>
  *
@@ -29,12 +29,24 @@
 
 #include <XdgIcon>
 #include <LXQt/Settings>
+#include <QCommandLineParser>
 
 #include "sessionconfigwindow.h"
 
 int main(int argc, char** argv)
 {
-    LxQt::SingleApplication a(argc, argv);
+    LXQt::SingleApplication a(argc, argv);
+    a.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QStringLiteral("LXQt Config Session"));
+    const QString VERINFO = QStringLiteral(LXQT_SESSION_VERSION
+                                           "\nliblxqt   " LXQT_VERSION
+                                           "\nQt        " QT_VERSION_STR);
+    a.setApplicationVersion(VERINFO);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    parser.process(a);
 
     SessionConfigWindow w;
     a.setActivationWindow(&w);
